@@ -1,8 +1,6 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 =head1 NAME
 
@@ -21,20 +19,20 @@ Version <= 1.0: All these functions will not be reported.
                   user    => "username",
                   password => "password",
                 };
- 
+
  task "list", sub {
    my @data = db select => {
             fields => "*",
             from  => "table",
             where  => "enabled=1",
           };
- 
+
   db insert => "table", {
            field1 => "value1",
             field2 => "value2",
             field3 => 5,
           };
- 
+
   db update => "table", {
               set => {
                 field1 => "newvalue",
@@ -42,11 +40,11 @@ Version <= 1.0: All these functions will not be reported.
               },
               where => "id=5",
            };
- 
+
   db delete => "table", {
             where => "id < 5",
           };
- 
+
  };
 
 
@@ -56,11 +54,10 @@ Version <= 1.0: All these functions will not be reported.
 
 package Rex::Commands::DB;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.3'; # VERSION
+our $VERSION = '1.14.3'; # VERSION
 
 BEGIN {
   use Rex::Require;
@@ -84,13 +81,13 @@ Do a database action.
           from  => "table",
           where  => "host='myhost'",
         };
- 
+
  db insert => "table", {
           field1 => "value1",
           field2 => "value2",
           field3 => 5,
         };
- 
+
  db update => "table", {
             set => {
               field1 => "newvalue",
@@ -98,7 +95,7 @@ Do a database action.
             },
             where => "id=5",
          };
- 
+
  db delete => "table", {
           where => "id < 5",
         };
