@@ -1,8 +1,6 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 =head1 NAME
 
@@ -19,31 +17,31 @@ All these functions are not idempotent.
 =head1 SYNOPSIS
 
  use Rex::Commands::SCM;
- 
+
  set repository => "myrepo",
     url => 'git@foo.bar:myrepo.git';
- 
+
  set repository => "myrepo2",
     url      => "https://foo.bar/myrepo",
     type     => "subversion",
     username => "myuser",
     password => "mypass";
- 
+
  task "checkout", sub {
    checkout "myrepo";
- 
+
    checkout "myrepo",
      path => "webapp";
- 
+
    checkout "myrepo",
      path   => "webapp",
      branch => 1.6;    # branch only for git
- 
+
    # For Git only, will replay any local commits on top of pulled commits
    checkout "myrepo",
      path   => "script_dir",
      rebase => TRUE;
- 
+
    checkout "myrepo2";
  };
 
@@ -54,11 +52,10 @@ All these functions are not idempotent.
 
 package Rex::Commands::SCM;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.4'; # VERSION
+our $VERSION = '1.14.3'; # VERSION
 
 use Rex::Logger;
 use Rex::Config;
