@@ -1,8 +1,6 @@
 #
 # (c) xiahou feng <fanyeren@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 =head1 NAME
 
@@ -15,9 +13,9 @@ With this module you can define hostgroups out of a command.
 =head1 SYNOPSIS
 
  use Rex::Group::Lookup::Command;
- 
+
  group "dbserver"  => lookup_command("cat ip.list | grep -v -E '^#'");
- 
+
  rex xxxx                            # dbserver
 
 =head1 EXPORTED FUNCTIONS
@@ -26,10 +24,10 @@ With this module you can define hostgroups out of a command.
 
 package Rex::Group::Lookup::Command;
 
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.8.1'; # VERSION
+our $VERSION = '1.14.3'; # VERSION
 
 require Rex::Exporter;
 use Rex -base;
