@@ -1,15 +1,13 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Interface::Shell::Csh;
 
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.8.1'; # VERSION
+our $VERSION = '1.14.3'; # VERSION
 
 use Rex::Interface::Shell::Base;
 use base qw(Rex::Interface::Shell::Base);
