@@ -1,9 +1,9 @@
 package Rex::SCM::Git;
 
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.6.0'; # VERSION
+our $VERSION = '1.14.3'; # VERSION
 
 use Cwd qw(getcwd);
 use Rex::Commands::Fs;
@@ -12,9 +12,9 @@ use Rex::Helper::Run;
 
 use vars qw($CHECKOUT_BRANCH_COMMAND $CHECKOUT_TAG_COMMAND $CLONE_COMMAND);
 
-$CLONE_COMMAND           = "git clone %s %s";
-$CHECKOUT_BRANCH_COMMAND = "git checkout -b %s origin/%s";
-$CHECKOUT_TAG_COMMAND    = "git checkout -b %s %s";
+$CLONE_COMMAND           = "git clone %s %s %s";
+$CHECKOUT_BRANCH_COMMAND = "git checkout -B %s origin/%s";
+$CHECKOUT_TAG_COMMAND    = "git checkout -B %s %s";
 
 sub new {
   my $that  = shift;
@@ -29,15 +29,70 @@ sub new {
 sub checkout {
   my ( $self, $repo_info, $checkout_to, $checkout_opt ) = @_;
 
-  if ( !is_dir($checkout_to) ) {
-    my $clone_cmd =
-      sprintf( $CLONE_COMMAND, $repo_info->{"url"}, basename($checkout_to) );
-    Rex::Logger::debug("clone_cmd: $clone_cmd (cwd: " . dirname($checkout_to). ")");
+  my %run_opt;
+  $run_opt{env} = $checkout_opt->{env} if ( $checkout_opt->{env} );
+  my $clone_args = join( " ", @{ $checkout_opt->{clone_args} || [''] } );
+
+  if ( is_dir("$checkout_to/.git") ) {
+    my $branch = $checkout_opt->{"branch"} || "master";
+    Rex::Logger::info( "Pulling "
+        . $repo_info->{"url"} . " to "
+        . ( $checkout_to ? $checkout_to : "." ) );
+
+    my $rebase = $checkout_opt->{"rebase"} ? '--rebase' : '';
+    my $out    = i_run "git pull $rebase origin $branch",
+      cwd     => $checkout_to,
+      fail_ok => 1,
+      %run_opt;
+
+    unless ( $? == 0 ) {
+      Rex::Logger::info( "Error pulling.", "warn" );
+      Rex::Logger::info($out);
+      die("Error pulling.");
+    }
+    else {
+      Rex::Logger::debug($out);
+    }
+
+    if ( exists $checkout_opt->{"tag"} ) {
+      my $tag          = $checkout_opt->{tag};
+      my $checkout_cmd = sprintf( $CHECKOUT_TAG_COMMAND, $tag, $tag );
+      Rex::Logger::info( "Switching to tag " . $tag );
+      $out = i_run "git fetch origin",
+        cwd     => $checkout_to,
+        fail_ok => 1,
+        %run_opt;
+
+      unless ( $? == 0 ) {
+        Rex::Logger::info( "Error switching to tag.", "warn" );
+        Rex::Logger::info($out);
+        die("Error switching to tag.");
+      }
+      else {
+        Rex::Logger::debug($out);
+      }
+      $out = i_run "$checkout_cmd", cwd => $checkout_to, fail_ok => 1, %run_opt;
+      unless ( $? == 0 ) {
+        Rex::Logger::info( "Error switching to tag.", "warn" );
+        Rex::Logger::info($out);
+        die("Error switching to tag.");
+      }
+      Rex::Logger::debug($out);
+    }
+  }
+  else {
+    my $clone_cmd = sprintf( $CLONE_COMMAND,
+      $clone_args, $repo_info->{"url"}, basename($checkout_to) );
+    Rex::Logger::debug(
+      "clone_cmd: $clone_cmd (cwd: " . dirname($checkout_to) . ")" );
 
     Rex::Logger::info( "Cloning "
         . $repo_info->{"url"} . " to "
         . ( $checkout_to ? $checkout_to : "." ) );
-    my $out = i_run "$clone_cmd", cwd => dirname($checkout_to), fail_ok => 1;
+    my $out = i_run "$clone_cmd",
+      cwd     => dirname($checkout_to),
+      fail_ok => 1,
+      %run_opt;
     unless ( $? == 0 ) {
       Rex::Logger::info( "Error cloning repository.", "warn" );
       Rex::Logger::info($out);
@@ -61,7 +116,7 @@ sub checkout {
 
       Rex::Logger::info( "Switching to branch " . $checkout_opt->{"branch"} );
 
-      $out = i_run "$checkout_cmd", cwd => $checkout_to, fail_ok => 1;
+      $out = i_run "$checkout_cmd", cwd => $checkout_to, fail_ok => 1, %run_opt;
       unless ( $? == 0 ) {
         Rex::Logger::info( "Error switching to branch.", "warn" );
         Rex::Logger::info($out);
@@ -78,7 +133,7 @@ sub checkout {
       );
 
       Rex::Logger::info( "Switching to tag " . $checkout_opt->{"tag"} );
-      $out = i_run "$checkout_cmd", cwd => $checkout_to, fail_ok => 1;
+      $out = i_run "$checkout_cmd", cwd => $checkout_to, fail_ok => 1, %run_opt;
       unless ( $? == 0 ) {
         Rex::Logger::info( "Error switching to tag.", "warn" );
         Rex::Logger::info($out);
@@ -87,53 +142,6 @@ sub checkout {
       Rex::Logger::debug($out);
     }
   }
-  elsif ( is_dir("$checkout_to/.git") ) {
-    my $branch = $checkout_opt->{"branch"} || "master";
-    Rex::Logger::info( "Pulling "
-        . $repo_info->{"url"} . " to "
-        . ( $checkout_to ? $checkout_to : "." ) );
-
-    my $rebase = $checkout_opt->{"rebase"} ? '--rebase' : '';
-    my $out = i_run "git pull $rebase origin $branch",
-      cwd     => $checkout_to,
-      fail_ok => 1;
-
-    unless ( $? == 0 ) {
-      Rex::Logger::info( "Error pulling.", "warn" );
-      Rex::Logger::info($out);
-      die("Error pulling.");
-    }
-    else {
-      Rex::Logger::debug($out);
-    }
-
-    if ( exists $checkout_opt->{"tag"} ) {
-      my $tag = $checkout_opt->{tag};
-      my $checkout_cmd = sprintf( $CHECKOUT_TAG_COMMAND, $tag, $tag );
-      Rex::Logger::info( "Switching to tag " . $tag );
-      $out = i_run "git fetch origin", cwd => $checkout_to, fail_ok => 1;
-
-      unless ( $? == 0 ) {
-        Rex::Logger::info( "Error switching to tag.", "warn" );
-        Rex::Logger::info($out);
-        die("Error switching to tag.");
-      }
-      else {
-        Rex::Logger::debug($out);
-      }
-      $out = i_run "$checkout_cmd", cwd => $checkout_to, fail_ok => 1;
-      unless ( $? == 0 ) {
-        Rex::Logger::info( "Error switching to tag.", "warn" );
-        Rex::Logger::info($out);
-        die("Error switching to tag.");
-      }
-      Rex::Logger::debug($out);
-    }
-  }
-  else {
-    Rex::Logger::info( "Error checking out repository.", "warn" );
-    die("Error checking out repository.");
-  }
 }
 
 1;
