@@ -3,11 +3,10 @@
 #
 package Rex::Service::ALT;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.3'; # VERSION
+our $VERSION = '1.14.3'; # VERSION
 
 use base qw(Rex::Service::Base);
 
